Index: include/v8.h |
diff --git a/include/v8.h b/include/v8.h |
index 92eb11bceca4c6d91db2c1c546d89a5262418a12..e783727c2db5ad7310136342d1aa9a55cb8f8dc1 100644 |
--- a/include/v8.h |
+++ b/include/v8.h |
@@ -2956,10 +2956,15 @@ class V8_EXPORT ArrayBuffer : public Object { |
bool IsExternal() const; |
/** |
+ * Returns true if this ArrayBuffer may be neutered. |
+ */ |
+ bool IsNeuterable() const; |
+ |
+ /** |
* Neuters this ArrayBuffer and all its views (typed arrays). |
* Neutering sets the byte length of the buffer and all typed arrays to zero, |
* preventing JavaScript from ever accessing underlying backing store. |
* ArrayBuffer should have been externalized. |
*/ |
void Neuter(); |
@@ -2956,10 +2956,15 @@ class V8_EXPORT ArrayBuffer : public Object { |
* Neutering sets the byte length of the buffer and all typed arrays to zero, |
* preventing JavaScript from ever accessing underlying backing store. |
- * ArrayBuffer should have been externalized. |
+ * ArrayBuffer should have been externalized and must be neuterable. |
*/ |
void Neuter(); |